import { CronJob } from 'cron';
import Log from './Log.js';
import LogFmt from './LogFmt.js';

export default class Job {

  static Cron = CronJob;

  static EVERY_MINUTE = '*/1 * * * *';
  static TWO_MINUTES = '*/2 * * * *';
  static FIVE_MINUTES = '*/5 * * * *';
  static TEN_MINUTES = '*/10 * * * *';
  static QUARTER_HOUR = '*/15 * * * *';
  static HALF_HOUR = '*/30 * * * *';

  static ONE_HOUR = '0 * * * *';
  static TWO_HOURS = '0 */2 * * *';
  static THREE_HOURS = '0 */3 * * *';
  static SIX_HOURS = '0 */6 * * *';
  static TWELVE_HOURS = '0 */12 * * *';

  static ONE_DAY = '0 0 * * *';

  static start(cronTime, callback, description) {
    const job = new this.Cron(cronTime, async () => {
      if (description) {
        Log.trace(
          LogFmt.name('cron-job')
            .string('job-name', description).string('state', 'started')
            .log()
        );
      }
      const start = Date.now();
      await callback();
      const elapsed = Date.now() - start;

      if (description) {
        Log.info(
          LogFmt.name('cron-job')
            .string('job-name', description).string('state', 'finished')
            .decimal('elapsed-ms', elapsed, 2)
            .log()
        );
      }
    });
    job.start();

    if (description) {
      Log.log(
        LogFmt.name('cron-job')
          .string('job-name', description)
          .string('cron-time', cronTime)
          .log()
      );
    }

    return job;
  }

}
