import assert from 'assert';
import LogFmt from '../src/LogFmt.js';

describe('LogFmt.js', function() {

  describe('#name(name)', function() {

    it('produces simple log', function() {
      var expected = "name='test-log'";
      var result = LogFmt.name("test-log").log();
      assert.deepStrictEqual(expected, result);
    });

    it('complete log', function() {
      var expected = "name='test-log' string-value='nice potato' number-value=3 decimal-value-one=12.2 decimal-value-two=45.22 boolean-value=1";
      var result = LogFmt.name("test-log")
        .string("string-value", "nice potato")
        .number("number-value", 3)
        .decimal("decimal-value-one", 12.244, 1)
        .decimal("decimal-value-two", 45.22234, 2)
        .bool("boolean-value", true)
        .log();

      assert.deepStrictEqual(expected, result);
    });

  });

  describe('#isStringLogFormat(log)', function() {

    it('false for a simple textlog', function() {
      var expected = false;
      var result = LogFmt.isStringLogFmt("Email sent to admin!");
      assert.deepStrictEqual(expected, result);
    });

    it('true for a logfmt log', function() {
      var expected = true;
      var result = LogFmt.isStringLogFmt("name='test-log'");
      assert.deepStrictEqual(expected, result);
    });

  });

});
